@@ -14,7 +14,7 @@ from sqlglot.schema import Schema, ensure_schema
 
 def qualify_columns(
     expression: exp.Expression,
-    schema: dict | Schema,
+    schema: t.Dict | Schema,
     expand_alias_refs: bool = True,
     infer_schema: t.Optional[bool] = None,
 ) -> exp.Expression:
@@ -93,7 +93,7 @@ def _pop_table_column_aliases(derived_tables):
 
 def _expand_using(scope, resolver):
     joins = list(scope.find_all(exp.Join))
-    names = {join.this.alias for join in joins}
+    names = {join.alias_or_name for join in joins}
     ordered = [key for key in scope.selected_sources if key not in names]
 
     # Mapping of automatically joined column names to an ordered set of source names (dict).
@@ -105,7 +105,7 @@ def _expand_using(scope, resolver):
         if not using:
             continue
 
-        join_table = join.this.alias_or_name
+        join_table = join.alias_or_name
 
         columns = {}
 
